@@ -64,6 +64,8 @@ static int nosocket;
 static int foreground;
 static const char *pidfile = ACPID_PIDFILE;
 static int netlink;
+const char *dropaction = DROP_ACTION;
+int tpmutefix = 0;
 
 int
 main(int argc, char **argv)
@@ -206,6 +208,8 @@ handle_cmdline(int *argc, char ***argv)
 		{"pidfile", 1, 0, 'p'},
 		{"lockfile", 1, 0, 'L'},
 		{"netlink", 0, 0, 'n'},
+		{"dropaction", 1, 0, 'r'},
+		{"tpmutefix", 0, 0, 't'},
 		{"version", 0, 0, 'v'},
 		{"help", 0, 0, 'h'},
 		{NULL, 0, 0, 0},
@@ -224,6 +228,8 @@ handle_cmdline(int *argc, char ***argv)
 		"Use the specified PID file.",		/* pidfile */
 		"Use the specified lockfile to stop processing.", /* lockfile */
 		"Force netlink/input layer mode. (overrides -e)", /* netlink */
+		"Define the pseudo-action to drop an event.", /* dropaction */
+		"Fixup for ThinkPad mute-repeat behaviour.", /* tpmutefix */
 		"Print version information.",		/* version */
 		"Print this message.",			/* help */
 	};
@@ -234,7 +240,7 @@ handle_cmdline(int *argc, char ***argv)
 	for (;;) {
 		int i;
 		i = getopt_long(*argc, *argv,
-		    "c:C:de:flg:m:s:Sp:L:nvh", opts, NULL);
+		    "c:C:de:flg:m:s:Sp:L:nr:tvh", opts, NULL);
 		if (i == -1) {
 			break;
 		}
@@ -280,6 +286,12 @@ handle_cmdline(int *argc, char ***argv)
 		case 'n':
 			netlink = 1;
 			break;
+		case 'r':
+			dropaction = optarg;
+			break;
+		case 't':
+			tpmutefix = 1;
+			break;
 		case 'v':
 			printf(PACKAGE "-" VERSION "\n");
 			exit(EXIT_SUCCESS);
